#ifndef NT2_INCLUDE_CONSTANTS_MTHREE_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MTHREE_HPP_INCLUDED

#include <nt2/constant/include/constants/mthree.hpp>

#endif
